@@ -52,7 +52,10 @@ def get_ui_slider(obj_name,default_value=0):
         if(obj_name in globals()["_data"]):
             v = globals()["_data"][obj_name]
             try:
+                vint = int(v)
                 v = float(v)
+                if( vint == v ):
+                    v = int(v)
             except:
                 0
             return v
